/**
* This file is a part of the Cairo-Dock project
*
* Copyright : (C) see the 'copyright' file.
* E-mail    : see the 'copyright' file.
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 3
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


#ifndef __RENDERING_DESKLET_PANEL__
#define  __RENDERING_DESKLET_PANEL__

#include "cairo-dock.h"


typedef struct {
	// from config
	gint iNbLinesForced;
	gboolean bHorizontalPackaging;
	gdouble fBgColor[4];
	gint iRadius;
	gint iLineWidth;
	// computed data
	gdouble fMargin;
	gint iNbIcons;
	gint iIconSize;
	gint iMainIconSize;
	gint iNbLines, iNbColumns;
	} CDPanelParameters;


void rendering_register_panel_desklet_renderer (void);


#endif
